@@ -16,7 +16,8 @@ air.boot <- boot(aircondit, mean.fun, R = 999)
 control(air.boot, index = 2, bias.adj = TRUE)
 air.cont <- control(air.boot, index = 2)
 # Now let us try the variance on the log scale.
-air.cont1 <- control(air.boot, t0=log(air.boot$t0[2]), t=log(air.boot$t[,2]))
+air.cont1 <- control(air.boot, t0=log(air.boot$t0[2]),
+                     t=log(air.boot$t[,2]))
 
 
 
